.. mre documentation master file, created by
   sphinx-quickstart on Mon Aug 20 18:50:20 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


.. mdinclude:: ../README.md

.. toctree::
   :hidden:

   self

.. toctree::
    :titlesonly:
    :name: Welcome
    :maxdepth: 2
    :caption: Contents

    doc/gettingstarted
    doc/toolbox
    doc/changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
